==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDataVisualization/QAbstract3DInputHandler_shell.h <==
#ifndef QABSTRACT3DINPUTHANDLER_SHELL_H
#define QABSTRACT3DINPUTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qabstract3dinputhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qevent.h>
#include <QtJambi/RegistryAPI>


class QAbstract3DInputHandler_shell : public QAbstract3DInputHandler, public QtJambiShellInterface
{
public:
    QAbstract3DInputHandler_shell(QObject* parent0 = nullptr);
    ~QAbstract3DInputHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mousePressEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mouseReleaseEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstract3DInputHandler_access : public QAbstract3DInputHandler
{
    jint __qt_prevDistance_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_previousInputPos_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setPrevDistance_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint distance0);
    void __qt_setPreviousInputPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID position0);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mousePressEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_touchEvent_QTouchEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QABSTRACT3DINPUTHANDLER_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiDataVisualization/QAbstract3DInputHandler_shell.h <==
#ifndef QABSTRACT3DINPUTHANDLER_SHELL_H
#define QABSTRACT3DINPUTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDataVisualization/qabstract3dinputhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtGui/qevent.h>
#include <QtJambi/RegistryAPI>


class QAbstract3DInputHandler_shell : public QAbstract3DInputHandler, public QtJambiShellInterface
{
public:
    QAbstract3DInputHandler_shell(QObject* parent0 = nullptr);
    ~QAbstract3DInputHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mousePressEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mouseReleaseEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstract3DInputHandler_access : public QAbstract3DInputHandler
{
    jint __qt_prevDistance(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_previousInputPos(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setPrevDistance_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint distance0);
    void __qt_setPreviousInputPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID position0);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mousePressEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_touchEvent_QTouchEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QABSTRACT3DINPUTHANDLER_SHELL_H
